VectorizedFrom

Trait VectorizedFrom 

pub trait VectorizedFrom<T>: Sized {
    // Required method
    fn vectorized_from(src: T) -> Self;
}
Implementation of trait From to vectorize into/from.

Standard From unfortunately is not autoimplemented for tuples and arrays and cant be implemented for them because of orphans restrictions. That how pair of traits VectorizedFrom/VectorizedInto could be useful. They are implemented for tuples and arrays. Their implementation is based on standard From, if From is implemented for elements of a tuple then VectorizedFrom/VectorizedInto implemented for collection containing them.

Sample

use type_constructor::prelude::*;
types!( single Single1 : i32 );
let src = ( 1, 3 );
let got = <( Single1, Single1 )>::vectorized_from( src );

Required Methods

fn vectorized_from(src: T) -> Self

Performs the conversion.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl VectorizedFrom<()> for ()

Source

impl<Id, Into1, const N: usize> VectorizedFrom<[Into1; N]> for [Id; N]
where Into1: Into<Id> + Clone,

Source

impl<Into1, Id1> VectorizedFrom<(Into1,)> for (Id1,)
where Into1: Into<Id1>,

Source

impl<Into1, Into2, Id1, Id2> VectorizedFrom<(Into1, Into2)> for (Id1, Id2)
where Into1: Into<Id1>, Into2: Into<Id2>,

Source

impl<Into1, Into2, Into3, Id1, Id2, Id3> VectorizedFrom<(Into1, Into2, Into3)> for (Id1, Id2, Id3)
where Into1: Into<Id1>, Into2: Into<Id2>, Into3: Into<Id3>,

Implementors